{
    package GCLang::RO::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Colecţie de cărţi',
        Items => 'Cărţi',
        NewItem => 'Carte nouă',
    
        Isbn => 'ISBN',
        Title => 'Tilu',
        Cover => 'Copertă',
        Authors => 'Autori',
        Publisher => 'Editură',
        Publication => 'Dată editare',
        Language => 'Limbă',
        Genre => 'Gen',
        Serie => 'Colecţie',
        Bookdescription => 'Descriere',
        Pages => 'Pagini',
        Read => 'Citită',
        Acquisition => 'Dată cumpărare',
        Edition => 'Ediţie',
        Format => 'Format',
        Comments => 'Comentarii',
        Url => 'Pagina web',
        Translator => 'Traducător',
        Artist => 'Artist',

        General => 'General',
        Details => 'Detalii',

        ReadNo => 'Necitită',
        ReadYes => 'Citită',
     );
}

1;
